
import type SuccessResponse from '@/js/lib/SuccessResponse.js';
import BingoGroup from './BingoGroup';
import Util from './Util';
import {
	Exclude, Type, Expose
} from 'class-transformer';

export default class BingoGoal {
	name: string;

	@Exclude({
		toPlainOnly: true
	})
	@Type(() => BingoGroup)
		group: BingoGroup;

	tags: string[];

	possible_spaces: number[];

	constructor(name: string, group: BingoGroup) {
		this.name = name;
		this.group = group;
		this.tags = [];
		this.possible_spaces = [];
	}

	@Expose()
	get group_id(): string {
		return this.group.name;
	}

	addTag(tag: string): SuccessResponse {
		if (this.tags.some(
			existingTag => Util.stringCompare(existingTag, tag)
		)) {
			return Util.returnSuccess(false, 'Tag already exists');
		}
		else {
			this.tags.push(tag);

			return Util.returnSuccess(true);
		}
	}

	removeTag(tag: string): SuccessResponse {
		if (!this.tags.some(
			existingTag => Util.stringCompare(existingTag, tag)
		)) {
			return Util.returnSuccess(false, 'Tag doesn\'t exist');
		}
		else {
			this.tags = this.tags.filter(
				existingTag => !Util.stringCompare(existingTag, tag)
			);

			return Util.returnSuccess(true);
		}
	}
}
